<?php

namespace Drupal\protected_submissions\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * ProtectedSubmissionsForm class.
 */
class ProtectedSubmissionsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'protected_submissions_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('protected_submissions.settings');
    // Page title field.
    $form['reject_message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Reject message:'),
      '#default_value' => $config->get('protected_submissions.reject_message'),
      '#description' => $this->t('Enter a message to display when submission of undesired pattern is attempted.'),
    ];
    // Source text field.
    $form['reject_patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Reject patterns:'),
      '#default_value' => $config->get('protected_submissions.reject_patterns'),
      '#description' => $this->t('Separating with commas or new lines, enter words or patterns to reject.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('protected_submissions.settings');
    $config->set('protected_submissions.reject_message', $form_state->getValue('reject_message'));
    $config->set('protected_submissions.reject_patterns', $form_state->getValue('reject_patterns'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'protected_submissions.settings',
    ];
  }

}
